# coding: utf-8

"""
    rds_mysql

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ListDBInstancesRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'create_end_time': 'str',
        'create_start_time': 'str',
        'instance_id': 'str',
        'instance_status': 'str',
        'instance_type': 'str',
        'limit': 'int',
        'offset': 'int',
        'region': 'str',
        'zone': 'str'
    }

    attribute_map = {
        'create_end_time': 'CreateEndTime',
        'create_start_time': 'CreateStartTime',
        'instance_id': 'InstanceId',
        'instance_status': 'InstanceStatus',
        'instance_type': 'InstanceType',
        'limit': 'Limit',
        'offset': 'Offset',
        'region': 'Region',
        'zone': 'Zone'
    }

    def __init__(self, create_end_time=None, create_start_time=None, instance_id=None, instance_status=None, instance_type=None, limit=None, offset=None, region=None, zone=None, _configuration=None):  # noqa: E501
        """ListDBInstancesRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._create_end_time = None
        self._create_start_time = None
        self._instance_id = None
        self._instance_status = None
        self._instance_type = None
        self._limit = None
        self._offset = None
        self._region = None
        self._zone = None
        self.discriminator = None

        if create_end_time is not None:
            self.create_end_time = create_end_time
        if create_start_time is not None:
            self.create_start_time = create_start_time
        if instance_id is not None:
            self.instance_id = instance_id
        if instance_status is not None:
            self.instance_status = instance_status
        if instance_type is not None:
            self.instance_type = instance_type
        if limit is not None:
            self.limit = limit
        if offset is not None:
            self.offset = offset
        if region is not None:
            self.region = region
        if zone is not None:
            self.zone = zone

    @property
    def create_end_time(self):
        """Gets the create_end_time of this ListDBInstancesRequest.  # noqa: E501


        :return: The create_end_time of this ListDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._create_end_time

    @create_end_time.setter
    def create_end_time(self, create_end_time):
        """Sets the create_end_time of this ListDBInstancesRequest.


        :param create_end_time: The create_end_time of this ListDBInstancesRequest.  # noqa: E501
        :type: str
        """

        self._create_end_time = create_end_time

    @property
    def create_start_time(self):
        """Gets the create_start_time of this ListDBInstancesRequest.  # noqa: E501


        :return: The create_start_time of this ListDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._create_start_time

    @create_start_time.setter
    def create_start_time(self, create_start_time):
        """Sets the create_start_time of this ListDBInstancesRequest.


        :param create_start_time: The create_start_time of this ListDBInstancesRequest.  # noqa: E501
        :type: str
        """

        self._create_start_time = create_start_time

    @property
    def instance_id(self):
        """Gets the instance_id of this ListDBInstancesRequest.  # noqa: E501


        :return: The instance_id of this ListDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this ListDBInstancesRequest.


        :param instance_id: The instance_id of this ListDBInstancesRequest.  # noqa: E501
        :type: str
        """

        self._instance_id = instance_id

    @property
    def instance_status(self):
        """Gets the instance_status of this ListDBInstancesRequest.  # noqa: E501


        :return: The instance_status of this ListDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_status

    @instance_status.setter
    def instance_status(self, instance_status):
        """Sets the instance_status of this ListDBInstancesRequest.


        :param instance_status: The instance_status of this ListDBInstancesRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["AllowListMaintaining", "Closed", "Closing", "CreateFailed", "Creating", "Deleting", "Destroyed", "Destroying", "Error", "Importing", "Maintaining", "MasterChanging", "Migrating", "Reclaiming", "Recycled", "Released", "Restarting", "Restoring", "Resuming", "Running", "SSLUpdating", "TDEUpdating", "Unknown", "Updating", "Upgrading", "WaitingPaid"]  # noqa: E501
        if (self._configuration.client_side_validation and
                instance_status not in allowed_values):
            raise ValueError(
                "Invalid value for `instance_status` ({0}), must be one of {1}"  # noqa: E501
                .format(instance_status, allowed_values)
            )

        self._instance_status = instance_status

    @property
    def instance_type(self):
        """Gets the instance_type of this ListDBInstancesRequest.  # noqa: E501


        :return: The instance_type of this ListDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_type

    @instance_type.setter
    def instance_type(self, instance_type):
        """Sets the instance_type of this ListDBInstancesRequest.


        :param instance_type: The instance_type of this ListDBInstancesRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["HA"]  # noqa: E501
        if (self._configuration.client_side_validation and
                instance_type not in allowed_values):
            raise ValueError(
                "Invalid value for `instance_type` ({0}), must be one of {1}"  # noqa: E501
                .format(instance_type, allowed_values)
            )

        self._instance_type = instance_type

    @property
    def limit(self):
        """Gets the limit of this ListDBInstancesRequest.  # noqa: E501


        :return: The limit of this ListDBInstancesRequest.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this ListDBInstancesRequest.


        :param limit: The limit of this ListDBInstancesRequest.  # noqa: E501
        :type: int
        """

        self._limit = limit

    @property
    def offset(self):
        """Gets the offset of this ListDBInstancesRequest.  # noqa: E501


        :return: The offset of this ListDBInstancesRequest.  # noqa: E501
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this ListDBInstancesRequest.


        :param offset: The offset of this ListDBInstancesRequest.  # noqa: E501
        :type: int
        """

        self._offset = offset

    @property
    def region(self):
        """Gets the region of this ListDBInstancesRequest.  # noqa: E501


        :return: The region of this ListDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this ListDBInstancesRequest.


        :param region: The region of this ListDBInstancesRequest.  # noqa: E501
        :type: str
        """

        self._region = region

    @property
    def zone(self):
        """Gets the zone of this ListDBInstancesRequest.  # noqa: E501


        :return: The zone of this ListDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._zone

    @zone.setter
    def zone(self, zone):
        """Sets the zone of this ListDBInstancesRequest.


        :param zone: The zone of this ListDBInstancesRequest.  # noqa: E501
        :type: str
        """

        self._zone = zone

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ListDBInstancesRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListDBInstancesRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ListDBInstancesRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    cr

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from volcenginesdkcr.api.cr_api import CRApi

# import models into sdk package
from volcenginesdkcr.models.chart_attribute_for_list_tags_output import ChartAttributeForListTagsOutput
from volcenginesdkcr.models.create_namespace_request import CreateNamespaceRequest
from volcenginesdkcr.models.create_namespace_response import CreateNamespaceResponse
from volcenginesdkcr.models.create_registry_request import CreateRegistryRequest
from volcenginesdkcr.models.create_registry_response import CreateRegistryResponse
from volcenginesdkcr.models.create_repository_request import CreateRepositoryRequest
from volcenginesdkcr.models.create_repository_response import CreateRepositoryResponse
from volcenginesdkcr.models.delete_namespace_request import DeleteNamespaceRequest
from volcenginesdkcr.models.delete_namespace_response import DeleteNamespaceResponse
from volcenginesdkcr.models.delete_registry_request import DeleteRegistryRequest
from volcenginesdkcr.models.delete_registry_response import DeleteRegistryResponse
from volcenginesdkcr.models.delete_repository_request import DeleteRepositoryRequest
from volcenginesdkcr.models.delete_repository_response import DeleteRepositoryResponse
from volcenginesdkcr.models.delete_tags_request import DeleteTagsRequest
from volcenginesdkcr.models.delete_tags_response import DeleteTagsResponse
from volcenginesdkcr.models.filter_for_get_vpc_endpoint_input import FilterForGetVpcEndpointInput
from volcenginesdkcr.models.filter_for_list_namespaces_input import FilterForListNamespacesInput
from volcenginesdkcr.models.filter_for_list_registries_input import FilterForListRegistriesInput
from volcenginesdkcr.models.filter_for_list_repositories_input import FilterForListRepositoriesInput
from volcenginesdkcr.models.filter_for_list_tags_input import FilterForListTagsInput
from volcenginesdkcr.models.get_authorization_token_request import GetAuthorizationTokenRequest
from volcenginesdkcr.models.get_authorization_token_response import GetAuthorizationTokenResponse
from volcenginesdkcr.models.get_public_endpoint_request import GetPublicEndpointRequest
from volcenginesdkcr.models.get_public_endpoint_response import GetPublicEndpointResponse
from volcenginesdkcr.models.get_user_request import GetUserRequest
from volcenginesdkcr.models.get_user_response import GetUserResponse
from volcenginesdkcr.models.get_vpc_endpoint_request import GetVpcEndpointRequest
from volcenginesdkcr.models.get_vpc_endpoint_response import GetVpcEndpointResponse
from volcenginesdkcr.models.image_attribute_for_list_tags_output import ImageAttributeForListTagsOutput
from volcenginesdkcr.models.item_for_list_domains_output import ItemForListDomainsOutput
from volcenginesdkcr.models.item_for_list_namespaces_output import ItemForListNamespacesOutput
from volcenginesdkcr.models.item_for_list_registries_output import ItemForListRegistriesOutput
from volcenginesdkcr.models.item_for_list_repositories_output import ItemForListRepositoriesOutput
from volcenginesdkcr.models.item_for_list_tags_output import ItemForListTagsOutput
from volcenginesdkcr.models.list_domains_request import ListDomainsRequest
from volcenginesdkcr.models.list_domains_response import ListDomainsResponse
from volcenginesdkcr.models.list_namespaces_request import ListNamespacesRequest
from volcenginesdkcr.models.list_namespaces_response import ListNamespacesResponse
from volcenginesdkcr.models.list_registries_request import ListRegistriesRequest
from volcenginesdkcr.models.list_registries_response import ListRegistriesResponse
from volcenginesdkcr.models.list_repositories_request import ListRepositoriesRequest
from volcenginesdkcr.models.list_repositories_response import ListRepositoriesResponse
from volcenginesdkcr.models.list_tags_request import ListTagsRequest
from volcenginesdkcr.models.list_tags_response import ListTagsResponse
from volcenginesdkcr.models.set_user_request import SetUserRequest
from volcenginesdkcr.models.set_user_response import SetUserResponse
from volcenginesdkcr.models.start_registry_request import StartRegistryRequest
from volcenginesdkcr.models.start_registry_response import StartRegistryResponse
from volcenginesdkcr.models.status_for_list_registries_input import StatusForListRegistriesInput
from volcenginesdkcr.models.status_for_list_registries_output import StatusForListRegistriesOutput
from volcenginesdkcr.models.update_public_endpoint_request import UpdatePublicEndpointRequest
from volcenginesdkcr.models.update_public_endpoint_response import UpdatePublicEndpointResponse
from volcenginesdkcr.models.update_repository_request import UpdateRepositoryRequest
from volcenginesdkcr.models.update_repository_response import UpdateRepositoryResponse
from volcenginesdkcr.models.update_vpc_endpoint_request import UpdateVpcEndpointRequest
from volcenginesdkcr.models.update_vpc_endpoint_response import UpdateVpcEndpointResponse
from volcenginesdkcr.models.vpc_for_get_vpc_endpoint_output import VpcForGetVpcEndpointOutput
from volcenginesdkcr.models.vpc_for_update_vpc_endpoint_input import VpcForUpdateVpcEndpointInput



# coding: utf-8

"""
    rds_mysql_v2

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class InstanceForDescribeDBInstancesOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'address_object': 'list[AddressObjectForDescribeDBInstancesOutput]',
        'allow_list_version': 'str',
        'charge_detail': 'ChargeDetailForDescribeDBInstancesOutput',
        'create_time': 'str',
        'db_engine_version': 'str',
        'instance_id': 'str',
        'instance_name': 'str',
        'instance_status': 'str',
        'lower_case_table_names': 'str',
        'maintenance_window': 'MaintenanceWindowForDescribeDBInstancesOutput',
        'node_number': 'int',
        'node_spec': 'str',
        'project_name': 'str',
        'region_id': 'str',
        'storage_space': 'int',
        'storage_type': 'str',
        'storage_use': 'int',
        'subnet_id': 'str',
        'time_zone': 'str',
        'vpc_id': 'str',
        'zone_id': 'str'
    }

    attribute_map = {
        'address_object': 'AddressObject',
        'allow_list_version': 'AllowListVersion',
        'charge_detail': 'ChargeDetail',
        'create_time': 'CreateTime',
        'db_engine_version': 'DBEngineVersion',
        'instance_id': 'InstanceId',
        'instance_name': 'InstanceName',
        'instance_status': 'InstanceStatus',
        'lower_case_table_names': 'LowerCaseTableNames',
        'maintenance_window': 'MaintenanceWindow',
        'node_number': 'NodeNumber',
        'node_spec': 'NodeSpec',
        'project_name': 'ProjectName',
        'region_id': 'RegionId',
        'storage_space': 'StorageSpace',
        'storage_type': 'StorageType',
        'storage_use': 'StorageUse',
        'subnet_id': 'SubnetId',
        'time_zone': 'TimeZone',
        'vpc_id': 'VpcId',
        'zone_id': 'ZoneId'
    }

    def __init__(self, address_object=None, allow_list_version=None, charge_detail=None, create_time=None, db_engine_version=None, instance_id=None, instance_name=None, instance_status=None, lower_case_table_names=None, maintenance_window=None, node_number=None, node_spec=None, project_name=None, region_id=None, storage_space=None, storage_type=None, storage_use=None, subnet_id=None, time_zone=None, vpc_id=None, zone_id=None, _configuration=None):  # noqa: E501
        """InstanceForDescribeDBInstancesOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._address_object = None
        self._allow_list_version = None
        self._charge_detail = None
        self._create_time = None
        self._db_engine_version = None
        self._instance_id = None
        self._instance_name = None
        self._instance_status = None
        self._lower_case_table_names = None
        self._maintenance_window = None
        self._node_number = None
        self._node_spec = None
        self._project_name = None
        self._region_id = None
        self._storage_space = None
        self._storage_type = None
        self._storage_use = None
        self._subnet_id = None
        self._time_zone = None
        self._vpc_id = None
        self._zone_id = None
        self.discriminator = None

        if address_object is not None:
            self.address_object = address_object
        if allow_list_version is not None:
            self.allow_list_version = allow_list_version
        if charge_detail is not None:
            self.charge_detail = charge_detail
        if create_time is not None:
            self.create_time = create_time
        if db_engine_version is not None:
            self.db_engine_version = db_engine_version
        if instance_id is not None:
            self.instance_id = instance_id
        if instance_name is not None:
            self.instance_name = instance_name
        if instance_status is not None:
            self.instance_status = instance_status
        if lower_case_table_names is not None:
            self.lower_case_table_names = lower_case_table_names
        if maintenance_window is not None:
            self.maintenance_window = maintenance_window
        if node_number is not None:
            self.node_number = node_number
        if node_spec is not None:
            self.node_spec = node_spec
        if project_name is not None:
            self.project_name = project_name
        if region_id is not None:
            self.region_id = region_id
        if storage_space is not None:
            self.storage_space = storage_space
        if storage_type is not None:
            self.storage_type = storage_type
        if storage_use is not None:
            self.storage_use = storage_use
        if subnet_id is not None:
            self.subnet_id = subnet_id
        if time_zone is not None:
            self.time_zone = time_zone
        if vpc_id is not None:
            self.vpc_id = vpc_id
        if zone_id is not None:
            self.zone_id = zone_id

    @property
    def address_object(self):
        """Gets the address_object of this InstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The address_object of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: list[AddressObjectForDescribeDBInstancesOutput]
        """
        return self._address_object

    @address_object.setter
    def address_object(self, address_object):
        """Sets the address_object of this InstanceForDescribeDBInstancesOutput.


        :param address_object: The address_object of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: list[AddressObjectForDescribeDBInstancesOutput]
        """

        self._address_object = address_object

    @property
    def allow_list_version(self):
        """Gets the allow_list_version of this InstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The allow_list_version of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._allow_list_version

    @allow_list_version.setter
    def allow_list_version(self, allow_list_version):
        """Sets the allow_list_version of this InstanceForDescribeDBInstancesOutput.


        :param allow_list_version: The allow_list_version of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._allow_list_version = allow_list_version

    @property
    def charge_detail(self):
        """Gets the charge_detail of this InstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The charge_detail of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: ChargeDetailForDescribeDBInstancesOutput
        """
        return self._charge_detail

    @charge_detail.setter
    def charge_detail(self, charge_detail):
        """Sets the charge_detail of this InstanceForDescribeDBInstancesOutput.


        :param charge_detail: The charge_detail of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: ChargeDetailForDescribeDBInstancesOutput
        """

        self._charge_detail = charge_detail

    @property
    def create_time(self):
        """Gets the create_time of this InstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The create_time of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this InstanceForDescribeDBInstancesOutput.


        :param create_time: The create_time of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._create_time = create_time

    @property
    def db_engine_version(self):
        """Gets the db_engine_version of this InstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The db_engine_version of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._db_engine_version

    @db_engine_version.setter
    def db_engine_version(self, db_engine_version):
        """Sets the db_engine_version of this InstanceForDescribeDBInstancesOutput.


        :param db_engine_version: The db_engine_version of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._db_engine_version = db_engine_version

    @property
    def instance_id(self):
        """Gets the instance_id of this InstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The instance_id of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this InstanceForDescribeDBInstancesOutput.


        :param instance_id: The instance_id of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._instance_id = instance_id

    @property
    def instance_name(self):
        """Gets the instance_name of this InstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The instance_name of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """Sets the instance_name of this InstanceForDescribeDBInstancesOutput.


        :param instance_name: The instance_name of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._instance_name = instance_name

    @property
    def instance_status(self):
        """Gets the instance_status of this InstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The instance_status of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_status

    @instance_status.setter
    def instance_status(self, instance_status):
        """Sets the instance_status of this InstanceForDescribeDBInstancesOutput.


        :param instance_status: The instance_status of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._instance_status = instance_status

    @property
    def lower_case_table_names(self):
        """Gets the lower_case_table_names of this InstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The lower_case_table_names of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._lower_case_table_names

    @lower_case_table_names.setter
    def lower_case_table_names(self, lower_case_table_names):
        """Sets the lower_case_table_names of this InstanceForDescribeDBInstancesOutput.


        :param lower_case_table_names: The lower_case_table_names of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._lower_case_table_names = lower_case_table_names

    @property
    def maintenance_window(self):
        """Gets the maintenance_window of this InstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The maintenance_window of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: MaintenanceWindowForDescribeDBInstancesOutput
        """
        return self._maintenance_window

    @maintenance_window.setter
    def maintenance_window(self, maintenance_window):
        """Sets the maintenance_window of this InstanceForDescribeDBInstancesOutput.


        :param maintenance_window: The maintenance_window of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: MaintenanceWindowForDescribeDBInstancesOutput
        """

        self._maintenance_window = maintenance_window

    @property
    def node_number(self):
        """Gets the node_number of this InstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The node_number of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: int
        """
        return self._node_number

    @node_number.setter
    def node_number(self, node_number):
        """Sets the node_number of this InstanceForDescribeDBInstancesOutput.


        :param node_number: The node_number of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: int
        """

        self._node_number = node_number

    @property
    def node_spec(self):
        """Gets the node_spec of this InstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The node_spec of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._node_spec

    @node_spec.setter
    def node_spec(self, node_spec):
        """Sets the node_spec of this InstanceForDescribeDBInstancesOutput.


        :param node_spec: The node_spec of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._node_spec = node_spec

    @property
    def project_name(self):
        """Gets the project_name of this InstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The project_name of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this InstanceForDescribeDBInstancesOutput.


        :param project_name: The project_name of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def region_id(self):
        """Gets the region_id of this InstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The region_id of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._region_id

    @region_id.setter
    def region_id(self, region_id):
        """Sets the region_id of this InstanceForDescribeDBInstancesOutput.


        :param region_id: The region_id of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._region_id = region_id

    @property
    def storage_space(self):
        """Gets the storage_space of this InstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The storage_space of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: int
        """
        return self._storage_space

    @storage_space.setter
    def storage_space(self, storage_space):
        """Sets the storage_space of this InstanceForDescribeDBInstancesOutput.


        :param storage_space: The storage_space of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: int
        """

        self._storage_space = storage_space

    @property
    def storage_type(self):
        """Gets the storage_type of this InstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The storage_type of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._storage_type

    @storage_type.setter
    def storage_type(self, storage_type):
        """Sets the storage_type of this InstanceForDescribeDBInstancesOutput.


        :param storage_type: The storage_type of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._storage_type = storage_type

    @property
    def storage_use(self):
        """Gets the storage_use of this InstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The storage_use of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: int
        """
        return self._storage_use

    @storage_use.setter
    def storage_use(self, storage_use):
        """Sets the storage_use of this InstanceForDescribeDBInstancesOutput.


        :param storage_use: The storage_use of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: int
        """

        self._storage_use = storage_use

    @property
    def subnet_id(self):
        """Gets the subnet_id of this InstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The subnet_id of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """Sets the subnet_id of this InstanceForDescribeDBInstancesOutput.


        :param subnet_id: The subnet_id of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._subnet_id = subnet_id

    @property
    def time_zone(self):
        """Gets the time_zone of this InstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The time_zone of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this InstanceForDescribeDBInstancesOutput.


        :param time_zone: The time_zone of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._time_zone = time_zone

    @property
    def vpc_id(self):
        """Gets the vpc_id of this InstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The vpc_id of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._vpc_id

    @vpc_id.setter
    def vpc_id(self, vpc_id):
        """Sets the vpc_id of this InstanceForDescribeDBInstancesOutput.


        :param vpc_id: The vpc_id of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._vpc_id = vpc_id

    @property
    def zone_id(self):
        """Gets the zone_id of this InstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The zone_id of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this InstanceForDescribeDBInstancesOutput.


        :param zone_id: The zone_id of this InstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._zone_id = zone_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InstanceForDescribeDBInstancesOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstanceForDescribeDBInstancesOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InstanceForDescribeDBInstancesOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    rds_mysql

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DataForListParameterTemplatesOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_id': 'str',
        'create_time': 'str',
        'need_restart': 'bool',
        'parameter_num': 'int',
        'template_category': 'str',
        'template_desc': 'str',
        'template_id': 'str',
        'template_name': 'str',
        'template_params': 'list[TemplateParamForListParameterTemplatesOutput]',
        'template_source': 'str',
        'template_type': 'str',
        'template_type_version': 'str',
        'update_time': 'str'
    }

    attribute_map = {
        'account_id': 'AccountId',
        'create_time': 'CreateTime',
        'need_restart': 'NeedRestart',
        'parameter_num': 'ParameterNum',
        'template_category': 'TemplateCategory',
        'template_desc': 'TemplateDesc',
        'template_id': 'TemplateId',
        'template_name': 'TemplateName',
        'template_params': 'TemplateParams',
        'template_source': 'TemplateSource',
        'template_type': 'TemplateType',
        'template_type_version': 'TemplateTypeVersion',
        'update_time': 'UpdateTime'
    }

    def __init__(self, account_id=None, create_time=None, need_restart=None, parameter_num=None, template_category=None, template_desc=None, template_id=None, template_name=None, template_params=None, template_source=None, template_type=None, template_type_version=None, update_time=None, _configuration=None):  # noqa: E501
        """DataForListParameterTemplatesOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._account_id = None
        self._create_time = None
        self._need_restart = None
        self._parameter_num = None
        self._template_category = None
        self._template_desc = None
        self._template_id = None
        self._template_name = None
        self._template_params = None
        self._template_source = None
        self._template_type = None
        self._template_type_version = None
        self._update_time = None
        self.discriminator = None

        if account_id is not None:
            self.account_id = account_id
        if create_time is not None:
            self.create_time = create_time
        if need_restart is not None:
            self.need_restart = need_restart
        if parameter_num is not None:
            self.parameter_num = parameter_num
        if template_category is not None:
            self.template_category = template_category
        if template_desc is not None:
            self.template_desc = template_desc
        if template_id is not None:
            self.template_id = template_id
        if template_name is not None:
            self.template_name = template_name
        if template_params is not None:
            self.template_params = template_params
        if template_source is not None:
            self.template_source = template_source
        if template_type is not None:
            self.template_type = template_type
        if template_type_version is not None:
            self.template_type_version = template_type_version
        if update_time is not None:
            self.update_time = update_time

    @property
    def account_id(self):
        """Gets the account_id of this DataForListParameterTemplatesOutput.  # noqa: E501


        :return: The account_id of this DataForListParameterTemplatesOutput.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this DataForListParameterTemplatesOutput.


        :param account_id: The account_id of this DataForListParameterTemplatesOutput.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def create_time(self):
        """Gets the create_time of this DataForListParameterTemplatesOutput.  # noqa: E501


        :return: The create_time of this DataForListParameterTemplatesOutput.  # noqa: E501
        :rtype: str
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this DataForListParameterTemplatesOutput.


        :param create_time: The create_time of this DataForListParameterTemplatesOutput.  # noqa: E501
        :type: str
        """

        self._create_time = create_time

    @property
    def need_restart(self):
        """Gets the need_restart of this DataForListParameterTemplatesOutput.  # noqa: E501


        :return: The need_restart of this DataForListParameterTemplatesOutput.  # noqa: E501
        :rtype: bool
        """
        return self._need_restart

    @need_restart.setter
    def need_restart(self, need_restart):
        """Sets the need_restart of this DataForListParameterTemplatesOutput.


        :param need_restart: The need_restart of this DataForListParameterTemplatesOutput.  # noqa: E501
        :type: bool
        """

        self._need_restart = need_restart

    @property
    def parameter_num(self):
        """Gets the parameter_num of this DataForListParameterTemplatesOutput.  # noqa: E501


        :return: The parameter_num of this DataForListParameterTemplatesOutput.  # noqa: E501
        :rtype: int
        """
        return self._parameter_num

    @parameter_num.setter
    def parameter_num(self, parameter_num):
        """Sets the parameter_num of this DataForListParameterTemplatesOutput.


        :param parameter_num: The parameter_num of this DataForListParameterTemplatesOutput.  # noqa: E501
        :type: int
        """

        self._parameter_num = parameter_num

    @property
    def template_category(self):
        """Gets the template_category of this DataForListParameterTemplatesOutput.  # noqa: E501


        :return: The template_category of this DataForListParameterTemplatesOutput.  # noqa: E501
        :rtype: str
        """
        return self._template_category

    @template_category.setter
    def template_category(self, template_category):
        """Sets the template_category of this DataForListParameterTemplatesOutput.


        :param template_category: The template_category of this DataForListParameterTemplatesOutput.  # noqa: E501
        :type: str
        """
        allowed_values = ["DBEngine", "Proxy"]  # noqa: E501
        if (self._configuration.client_side_validation and
                template_category not in allowed_values):
            raise ValueError(
                "Invalid value for `template_category` ({0}), must be one of {1}"  # noqa: E501
                .format(template_category, allowed_values)
            )

        self._template_category = template_category

    @property
    def template_desc(self):
        """Gets the template_desc of this DataForListParameterTemplatesOutput.  # noqa: E501


        :return: The template_desc of this DataForListParameterTemplatesOutput.  # noqa: E501
        :rtype: str
        """
        return self._template_desc

    @template_desc.setter
    def template_desc(self, template_desc):
        """Sets the template_desc of this DataForListParameterTemplatesOutput.


        :param template_desc: The template_desc of this DataForListParameterTemplatesOutput.  # noqa: E501
        :type: str
        """

        self._template_desc = template_desc

    @property
    def template_id(self):
        """Gets the template_id of this DataForListParameterTemplatesOutput.  # noqa: E501


        :return: The template_id of this DataForListParameterTemplatesOutput.  # noqa: E501
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this DataForListParameterTemplatesOutput.


        :param template_id: The template_id of this DataForListParameterTemplatesOutput.  # noqa: E501
        :type: str
        """

        self._template_id = template_id

    @property
    def template_name(self):
        """Gets the template_name of this DataForListParameterTemplatesOutput.  # noqa: E501


        :return: The template_name of this DataForListParameterTemplatesOutput.  # noqa: E501
        :rtype: str
        """
        return self._template_name

    @template_name.setter
    def template_name(self, template_name):
        """Sets the template_name of this DataForListParameterTemplatesOutput.


        :param template_name: The template_name of this DataForListParameterTemplatesOutput.  # noqa: E501
        :type: str
        """

        self._template_name = template_name

    @property
    def template_params(self):
        """Gets the template_params of this DataForListParameterTemplatesOutput.  # noqa: E501


        :return: The template_params of this DataForListParameterTemplatesOutput.  # noqa: E501
        :rtype: list[TemplateParamForListParameterTemplatesOutput]
        """
        return self._template_params

    @template_params.setter
    def template_params(self, template_params):
        """Sets the template_params of this DataForListParameterTemplatesOutput.


        :param template_params: The template_params of this DataForListParameterTemplatesOutput.  # noqa: E501
        :type: list[TemplateParamForListParameterTemplatesOutput]
        """

        self._template_params = template_params

    @property
    def template_source(self):
        """Gets the template_source of this DataForListParameterTemplatesOutput.  # noqa: E501


        :return: The template_source of this DataForListParameterTemplatesOutput.  # noqa: E501
        :rtype: str
        """
        return self._template_source

    @template_source.setter
    def template_source(self, template_source):
        """Sets the template_source of this DataForListParameterTemplatesOutput.


        :param template_source: The template_source of this DataForListParameterTemplatesOutput.  # noqa: E501
        :type: str
        """
        allowed_values = ["System", "User"]  # noqa: E501
        if (self._configuration.client_side_validation and
                template_source not in allowed_values):
            raise ValueError(
                "Invalid value for `template_source` ({0}), must be one of {1}"  # noqa: E501
                .format(template_source, allowed_values)
            )

        self._template_source = template_source

    @property
    def template_type(self):
        """Gets the template_type of this DataForListParameterTemplatesOutput.  # noqa: E501


        :return: The template_type of this DataForListParameterTemplatesOutput.  # noqa: E501
        :rtype: str
        """
        return self._template_type

    @template_type.setter
    def template_type(self, template_type):
        """Sets the template_type of this DataForListParameterTemplatesOutput.


        :param template_type: The template_type of this DataForListParameterTemplatesOutput.  # noqa: E501
        :type: str
        """
        allowed_values = ["MySQL"]  # noqa: E501
        if (self._configuration.client_side_validation and
                template_type not in allowed_values):
            raise ValueError(
                "Invalid value for `template_type` ({0}), must be one of {1}"  # noqa: E501
                .format(template_type, allowed_values)
            )

        self._template_type = template_type

    @property
    def template_type_version(self):
        """Gets the template_type_version of this DataForListParameterTemplatesOutput.  # noqa: E501


        :return: The template_type_version of this DataForListParameterTemplatesOutput.  # noqa: E501
        :rtype: str
        """
        return self._template_type_version

    @template_type_version.setter
    def template_type_version(self, template_type_version):
        """Sets the template_type_version of this DataForListParameterTemplatesOutput.


        :param template_type_version: The template_type_version of this DataForListParameterTemplatesOutput.  # noqa: E501
        :type: str
        """
        allowed_values = ["MySQL_8_0", "MySQL_Community_5_7"]  # noqa: E501
        if (self._configuration.client_side_validation and
                template_type_version not in allowed_values):
            raise ValueError(
                "Invalid value for `template_type_version` ({0}), must be one of {1}"  # noqa: E501
                .format(template_type_version, allowed_values)
            )

        self._template_type_version = template_type_version

    @property
    def update_time(self):
        """Gets the update_time of this DataForListParameterTemplatesOutput.  # noqa: E501


        :return: The update_time of this DataForListParameterTemplatesOutput.  # noqa: E501
        :rtype: str
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this DataForListParameterTemplatesOutput.


        :param update_time: The update_time of this DataForListParameterTemplatesOutput.  # noqa: E501
        :type: str
        """

        self._update_time = update_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DataForListParameterTemplatesOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DataForListParameterTemplatesOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DataForListParameterTemplatesOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    rds_mysql_v2

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class AddressForDescribeDBInstanceDetailOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dns_visibility': 'bool',
        'domain': 'str',
        'eip_id': 'str',
        'ip_address': 'str',
        'network_type': 'str',
        'port': 'str',
        'subnet_id': 'str'
    }

    attribute_map = {
        'dns_visibility': 'DNSVisibility',
        'domain': 'Domain',
        'eip_id': 'EipId',
        'ip_address': 'IPAddress',
        'network_type': 'NetworkType',
        'port': 'Port',
        'subnet_id': 'SubnetId'
    }

    def __init__(self, dns_visibility=None, domain=None, eip_id=None, ip_address=None, network_type=None, port=None, subnet_id=None, _configuration=None):  # noqa: E501
        """AddressForDescribeDBInstanceDetailOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._dns_visibility = None
        self._domain = None
        self._eip_id = None
        self._ip_address = None
        self._network_type = None
        self._port = None
        self._subnet_id = None
        self.discriminator = None

        if dns_visibility is not None:
            self.dns_visibility = dns_visibility
        if domain is not None:
            self.domain = domain
        if eip_id is not None:
            self.eip_id = eip_id
        if ip_address is not None:
            self.ip_address = ip_address
        if network_type is not None:
            self.network_type = network_type
        if port is not None:
            self.port = port
        if subnet_id is not None:
            self.subnet_id = subnet_id

    @property
    def dns_visibility(self):
        """Gets the dns_visibility of this AddressForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The dns_visibility of this AddressForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: bool
        """
        return self._dns_visibility

    @dns_visibility.setter
    def dns_visibility(self, dns_visibility):
        """Sets the dns_visibility of this AddressForDescribeDBInstanceDetailOutput.


        :param dns_visibility: The dns_visibility of this AddressForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: bool
        """

        self._dns_visibility = dns_visibility

    @property
    def domain(self):
        """Gets the domain of this AddressForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The domain of this AddressForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this AddressForDescribeDBInstanceDetailOutput.


        :param domain: The domain of this AddressForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._domain = domain

    @property
    def eip_id(self):
        """Gets the eip_id of this AddressForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The eip_id of this AddressForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._eip_id

    @eip_id.setter
    def eip_id(self, eip_id):
        """Sets the eip_id of this AddressForDescribeDBInstanceDetailOutput.


        :param eip_id: The eip_id of this AddressForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._eip_id = eip_id

    @property
    def ip_address(self):
        """Gets the ip_address of this AddressForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The ip_address of this AddressForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this AddressForDescribeDBInstanceDetailOutput.


        :param ip_address: The ip_address of this AddressForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def network_type(self):
        """Gets the network_type of this AddressForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The network_type of this AddressForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._network_type

    @network_type.setter
    def network_type(self, network_type):
        """Sets the network_type of this AddressForDescribeDBInstanceDetailOutput.


        :param network_type: The network_type of this AddressForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._network_type = network_type

    @property
    def port(self):
        """Gets the port of this AddressForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The port of this AddressForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this AddressForDescribeDBInstanceDetailOutput.


        :param port: The port of this AddressForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._port = port

    @property
    def subnet_id(self):
        """Gets the subnet_id of this AddressForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The subnet_id of this AddressForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """Sets the subnet_id of this AddressForDescribeDBInstanceDetailOutput.


        :param subnet_id: The subnet_id of this AddressForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._subnet_id = subnet_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddressForDescribeDBInstanceDetailOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddressForDescribeDBInstanceDetailOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddressForDescribeDBInstanceDetailOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    redis

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DescribeDBInstanceDetailResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'capacity': 'CapacityForDescribeDBInstanceDetailOutput',
        'charge_type': 'str',
        'create_time': 'str',
        'deletion_protection': 'str',
        'engine_version': 'str',
        'expired_time': 'str',
        'instance_id': 'str',
        'instance_name': 'str',
        'maintenance_time': 'str',
        'node_number': 'int',
        'project_name': 'str',
        'region_id': 'str',
        'shard_capacity': 'float',
        'shard_number': 'int',
        'sharded_cluster': 'int',
        'status': 'str',
        'visit_addrs': 'list[VisitAddrForDescribeDBInstanceDetailOutput]',
        'vpc_auth_mode': 'str',
        'vpc_id': 'str',
        'zone_ids': 'list[str]'
    }

    attribute_map = {
        'capacity': 'Capacity',
        'charge_type': 'ChargeType',
        'create_time': 'CreateTime',
        'deletion_protection': 'DeletionProtection',
        'engine_version': 'EngineVersion',
        'expired_time': 'ExpiredTime',
        'instance_id': 'InstanceId',
        'instance_name': 'InstanceName',
        'maintenance_time': 'MaintenanceTime',
        'node_number': 'NodeNumber',
        'project_name': 'ProjectName',
        'region_id': 'RegionId',
        'shard_capacity': 'ShardCapacity',
        'shard_number': 'ShardNumber',
        'sharded_cluster': 'ShardedCluster',
        'status': 'Status',
        'visit_addrs': 'VisitAddrs',
        'vpc_auth_mode': 'VpcAuthMode',
        'vpc_id': 'VpcId',
        'zone_ids': 'ZoneIds'
    }

    def __init__(self, capacity=None, charge_type=None, create_time=None, deletion_protection=None, engine_version=None, expired_time=None, instance_id=None, instance_name=None, maintenance_time=None, node_number=None, project_name=None, region_id=None, shard_capacity=None, shard_number=None, sharded_cluster=None, status=None, visit_addrs=None, vpc_auth_mode=None, vpc_id=None, zone_ids=None, _configuration=None):  # noqa: E501
        """DescribeDBInstanceDetailResponse - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._capacity = None
        self._charge_type = None
        self._create_time = None
        self._deletion_protection = None
        self._engine_version = None
        self._expired_time = None
        self._instance_id = None
        self._instance_name = None
        self._maintenance_time = None
        self._node_number = None
        self._project_name = None
        self._region_id = None
        self._shard_capacity = None
        self._shard_number = None
        self._sharded_cluster = None
        self._status = None
        self._visit_addrs = None
        self._vpc_auth_mode = None
        self._vpc_id = None
        self._zone_ids = None
        self.discriminator = None

        if capacity is not None:
            self.capacity = capacity
        if charge_type is not None:
            self.charge_type = charge_type
        if create_time is not None:
            self.create_time = create_time
        if deletion_protection is not None:
            self.deletion_protection = deletion_protection
        if engine_version is not None:
            self.engine_version = engine_version
        if expired_time is not None:
            self.expired_time = expired_time
        if instance_id is not None:
            self.instance_id = instance_id
        if instance_name is not None:
            self.instance_name = instance_name
        if maintenance_time is not None:
            self.maintenance_time = maintenance_time
        if node_number is not None:
            self.node_number = node_number
        if project_name is not None:
            self.project_name = project_name
        if region_id is not None:
            self.region_id = region_id
        if shard_capacity is not None:
            self.shard_capacity = shard_capacity
        if shard_number is not None:
            self.shard_number = shard_number
        if sharded_cluster is not None:
            self.sharded_cluster = sharded_cluster
        if status is not None:
            self.status = status
        if visit_addrs is not None:
            self.visit_addrs = visit_addrs
        if vpc_auth_mode is not None:
            self.vpc_auth_mode = vpc_auth_mode
        if vpc_id is not None:
            self.vpc_id = vpc_id
        if zone_ids is not None:
            self.zone_ids = zone_ids

    @property
    def capacity(self):
        """Gets the capacity of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The capacity of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: CapacityForDescribeDBInstanceDetailOutput
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this DescribeDBInstanceDetailResponse.


        :param capacity: The capacity of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: CapacityForDescribeDBInstanceDetailOutput
        """

        self._capacity = capacity

    @property
    def charge_type(self):
        """Gets the charge_type of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The charge_type of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: str
        """
        return self._charge_type

    @charge_type.setter
    def charge_type(self, charge_type):
        """Sets the charge_type of this DescribeDBInstanceDetailResponse.


        :param charge_type: The charge_type of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: str
        """

        self._charge_type = charge_type

    @property
    def create_time(self):
        """Gets the create_time of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The create_time of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: str
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this DescribeDBInstanceDetailResponse.


        :param create_time: The create_time of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: str
        """

        self._create_time = create_time

    @property
    def deletion_protection(self):
        """Gets the deletion_protection of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The deletion_protection of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: str
        """
        return self._deletion_protection

    @deletion_protection.setter
    def deletion_protection(self, deletion_protection):
        """Sets the deletion_protection of this DescribeDBInstanceDetailResponse.


        :param deletion_protection: The deletion_protection of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: str
        """

        self._deletion_protection = deletion_protection

    @property
    def engine_version(self):
        """Gets the engine_version of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The engine_version of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: str
        """
        return self._engine_version

    @engine_version.setter
    def engine_version(self, engine_version):
        """Sets the engine_version of this DescribeDBInstanceDetailResponse.


        :param engine_version: The engine_version of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: str
        """

        self._engine_version = engine_version

    @property
    def expired_time(self):
        """Gets the expired_time of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The expired_time of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: str
        """
        return self._expired_time

    @expired_time.setter
    def expired_time(self, expired_time):
        """Sets the expired_time of this DescribeDBInstanceDetailResponse.


        :param expired_time: The expired_time of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: str
        """

        self._expired_time = expired_time

    @property
    def instance_id(self):
        """Gets the instance_id of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The instance_id of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this DescribeDBInstanceDetailResponse.


        :param instance_id: The instance_id of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: str
        """

        self._instance_id = instance_id

    @property
    def instance_name(self):
        """Gets the instance_name of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The instance_name of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """Sets the instance_name of this DescribeDBInstanceDetailResponse.


        :param instance_name: The instance_name of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: str
        """

        self._instance_name = instance_name

    @property
    def maintenance_time(self):
        """Gets the maintenance_time of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The maintenance_time of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: str
        """
        return self._maintenance_time

    @maintenance_time.setter
    def maintenance_time(self, maintenance_time):
        """Sets the maintenance_time of this DescribeDBInstanceDetailResponse.


        :param maintenance_time: The maintenance_time of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: str
        """

        self._maintenance_time = maintenance_time

    @property
    def node_number(self):
        """Gets the node_number of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The node_number of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: int
        """
        return self._node_number

    @node_number.setter
    def node_number(self, node_number):
        """Sets the node_number of this DescribeDBInstanceDetailResponse.


        :param node_number: The node_number of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: int
        """

        self._node_number = node_number

    @property
    def project_name(self):
        """Gets the project_name of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The project_name of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this DescribeDBInstanceDetailResponse.


        :param project_name: The project_name of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def region_id(self):
        """Gets the region_id of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The region_id of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: str
        """
        return self._region_id

    @region_id.setter
    def region_id(self, region_id):
        """Sets the region_id of this DescribeDBInstanceDetailResponse.


        :param region_id: The region_id of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: str
        """

        self._region_id = region_id

    @property
    def shard_capacity(self):
        """Gets the shard_capacity of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The shard_capacity of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: float
        """
        return self._shard_capacity

    @shard_capacity.setter
    def shard_capacity(self, shard_capacity):
        """Sets the shard_capacity of this DescribeDBInstanceDetailResponse.


        :param shard_capacity: The shard_capacity of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: float
        """

        self._shard_capacity = shard_capacity

    @property
    def shard_number(self):
        """Gets the shard_number of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The shard_number of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: int
        """
        return self._shard_number

    @shard_number.setter
    def shard_number(self, shard_number):
        """Sets the shard_number of this DescribeDBInstanceDetailResponse.


        :param shard_number: The shard_number of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: int
        """

        self._shard_number = shard_number

    @property
    def sharded_cluster(self):
        """Gets the sharded_cluster of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The sharded_cluster of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: int
        """
        return self._sharded_cluster

    @sharded_cluster.setter
    def sharded_cluster(self, sharded_cluster):
        """Sets the sharded_cluster of this DescribeDBInstanceDetailResponse.


        :param sharded_cluster: The sharded_cluster of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: int
        """

        self._sharded_cluster = sharded_cluster

    @property
    def status(self):
        """Gets the status of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The status of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DescribeDBInstanceDetailResponse.


        :param status: The status of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def visit_addrs(self):
        """Gets the visit_addrs of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The visit_addrs of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: list[VisitAddrForDescribeDBInstanceDetailOutput]
        """
        return self._visit_addrs

    @visit_addrs.setter
    def visit_addrs(self, visit_addrs):
        """Sets the visit_addrs of this DescribeDBInstanceDetailResponse.


        :param visit_addrs: The visit_addrs of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: list[VisitAddrForDescribeDBInstanceDetailOutput]
        """

        self._visit_addrs = visit_addrs

    @property
    def vpc_auth_mode(self):
        """Gets the vpc_auth_mode of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The vpc_auth_mode of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: str
        """
        return self._vpc_auth_mode

    @vpc_auth_mode.setter
    def vpc_auth_mode(self, vpc_auth_mode):
        """Sets the vpc_auth_mode of this DescribeDBInstanceDetailResponse.


        :param vpc_auth_mode: The vpc_auth_mode of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: str
        """

        self._vpc_auth_mode = vpc_auth_mode

    @property
    def vpc_id(self):
        """Gets the vpc_id of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The vpc_id of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: str
        """
        return self._vpc_id

    @vpc_id.setter
    def vpc_id(self, vpc_id):
        """Sets the vpc_id of this DescribeDBInstanceDetailResponse.


        :param vpc_id: The vpc_id of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: str
        """

        self._vpc_id = vpc_id

    @property
    def zone_ids(self):
        """Gets the zone_ids of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The zone_ids of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._zone_ids

    @zone_ids.setter
    def zone_ids(self, zone_ids):
        """Sets the zone_ids of this DescribeDBInstanceDetailResponse.


        :param zone_ids: The zone_ids of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: list[str]
        """

        self._zone_ids = zone_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DescribeDBInstanceDetailResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DescribeDBInstanceDetailResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DescribeDBInstanceDetailResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    vpn

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DescribeVpnConnectionsRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'customer_gateway_id': 'str',
        'page_number': 'int',
        'page_size': 'int',
        'project_name': 'str',
        'vpn_connection_ids': 'list[str]',
        'vpn_connection_name': 'str',
        'vpn_gateway_id': 'str'
    }

    attribute_map = {
        'customer_gateway_id': 'CustomerGatewayId',
        'page_number': 'PageNumber',
        'page_size': 'PageSize',
        'project_name': 'ProjectName',
        'vpn_connection_ids': 'VpnConnectionIds',
        'vpn_connection_name': 'VpnConnectionName',
        'vpn_gateway_id': 'VpnGatewayId'
    }

    def __init__(self, customer_gateway_id=None, page_number=None, page_size=None, project_name=None, vpn_connection_ids=None, vpn_connection_name=None, vpn_gateway_id=None, _configuration=None):  # noqa: E501
        """DescribeVpnConnectionsRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._customer_gateway_id = None
        self._page_number = None
        self._page_size = None
        self._project_name = None
        self._vpn_connection_ids = None
        self._vpn_connection_name = None
        self._vpn_gateway_id = None
        self.discriminator = None

        if customer_gateway_id is not None:
            self.customer_gateway_id = customer_gateway_id
        if page_number is not None:
            self.page_number = page_number
        if page_size is not None:
            self.page_size = page_size
        if project_name is not None:
            self.project_name = project_name
        if vpn_connection_ids is not None:
            self.vpn_connection_ids = vpn_connection_ids
        if vpn_connection_name is not None:
            self.vpn_connection_name = vpn_connection_name
        if vpn_gateway_id is not None:
            self.vpn_gateway_id = vpn_gateway_id

    @property
    def customer_gateway_id(self):
        """Gets the customer_gateway_id of this DescribeVpnConnectionsRequest.  # noqa: E501


        :return: The customer_gateway_id of this DescribeVpnConnectionsRequest.  # noqa: E501
        :rtype: str
        """
        return self._customer_gateway_id

    @customer_gateway_id.setter
    def customer_gateway_id(self, customer_gateway_id):
        """Sets the customer_gateway_id of this DescribeVpnConnectionsRequest.


        :param customer_gateway_id: The customer_gateway_id of this DescribeVpnConnectionsRequest.  # noqa: E501
        :type: str
        """

        self._customer_gateway_id = customer_gateway_id

    @property
    def page_number(self):
        """Gets the page_number of this DescribeVpnConnectionsRequest.  # noqa: E501


        :return: The page_number of this DescribeVpnConnectionsRequest.  # noqa: E501
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """Sets the page_number of this DescribeVpnConnectionsRequest.


        :param page_number: The page_number of this DescribeVpnConnectionsRequest.  # noqa: E501
        :type: int
        """

        self._page_number = page_number

    @property
    def page_size(self):
        """Gets the page_size of this DescribeVpnConnectionsRequest.  # noqa: E501


        :return: The page_size of this DescribeVpnConnectionsRequest.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this DescribeVpnConnectionsRequest.


        :param page_size: The page_size of this DescribeVpnConnectionsRequest.  # noqa: E501
        :type: int
        """

        self._page_size = page_size

    @property
    def project_name(self):
        """Gets the project_name of this DescribeVpnConnectionsRequest.  # noqa: E501


        :return: The project_name of this DescribeVpnConnectionsRequest.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this DescribeVpnConnectionsRequest.


        :param project_name: The project_name of this DescribeVpnConnectionsRequest.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def vpn_connection_ids(self):
        """Gets the vpn_connection_ids of this DescribeVpnConnectionsRequest.  # noqa: E501


        :return: The vpn_connection_ids of this DescribeVpnConnectionsRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._vpn_connection_ids

    @vpn_connection_ids.setter
    def vpn_connection_ids(self, vpn_connection_ids):
        """Sets the vpn_connection_ids of this DescribeVpnConnectionsRequest.


        :param vpn_connection_ids: The vpn_connection_ids of this DescribeVpnConnectionsRequest.  # noqa: E501
        :type: list[str]
        """

        self._vpn_connection_ids = vpn_connection_ids

    @property
    def vpn_connection_name(self):
        """Gets the vpn_connection_name of this DescribeVpnConnectionsRequest.  # noqa: E501


        :return: The vpn_connection_name of this DescribeVpnConnectionsRequest.  # noqa: E501
        :rtype: str
        """
        return self._vpn_connection_name

    @vpn_connection_name.setter
    def vpn_connection_name(self, vpn_connection_name):
        """Sets the vpn_connection_name of this DescribeVpnConnectionsRequest.


        :param vpn_connection_name: The vpn_connection_name of this DescribeVpnConnectionsRequest.  # noqa: E501
        :type: str
        """

        self._vpn_connection_name = vpn_connection_name

    @property
    def vpn_gateway_id(self):
        """Gets the vpn_gateway_id of this DescribeVpnConnectionsRequest.  # noqa: E501


        :return: The vpn_gateway_id of this DescribeVpnConnectionsRequest.  # noqa: E501
        :rtype: str
        """
        return self._vpn_gateway_id

    @vpn_gateway_id.setter
    def vpn_gateway_id(self, vpn_gateway_id):
        """Sets the vpn_gateway_id of this DescribeVpnConnectionsRequest.


        :param vpn_gateway_id: The vpn_gateway_id of this DescribeVpnConnectionsRequest.  # noqa: E501
        :type: str
        """

        self._vpn_gateway_id = vpn_gateway_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DescribeVpnConnectionsRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DescribeVpnConnectionsRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DescribeVpnConnectionsRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    rds_mysql

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ListParameterTemplatesRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'template_category': 'str',
        'template_source': 'str',
        'template_type': 'str',
        'template_type_version': 'str'
    }

    attribute_map = {
        'template_category': 'TemplateCategory',
        'template_source': 'TemplateSource',
        'template_type': 'TemplateType',
        'template_type_version': 'TemplateTypeVersion'
    }

    def __init__(self, template_category=None, template_source=None, template_type=None, template_type_version=None, _configuration=None):  # noqa: E501
        """ListParameterTemplatesRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._template_category = None
        self._template_source = None
        self._template_type = None
        self._template_type_version = None
        self.discriminator = None

        if template_category is not None:
            self.template_category = template_category
        if template_source is not None:
            self.template_source = template_source
        if template_type is not None:
            self.template_type = template_type
        if template_type_version is not None:
            self.template_type_version = template_type_version

    @property
    def template_category(self):
        """Gets the template_category of this ListParameterTemplatesRequest.  # noqa: E501


        :return: The template_category of this ListParameterTemplatesRequest.  # noqa: E501
        :rtype: str
        """
        return self._template_category

    @template_category.setter
    def template_category(self, template_category):
        """Sets the template_category of this ListParameterTemplatesRequest.


        :param template_category: The template_category of this ListParameterTemplatesRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["DBEngine", "Proxy"]  # noqa: E501
        if (self._configuration.client_side_validation and
                template_category not in allowed_values):
            raise ValueError(
                "Invalid value for `template_category` ({0}), must be one of {1}"  # noqa: E501
                .format(template_category, allowed_values)
            )

        self._template_category = template_category

    @property
    def template_source(self):
        """Gets the template_source of this ListParameterTemplatesRequest.  # noqa: E501


        :return: The template_source of this ListParameterTemplatesRequest.  # noqa: E501
        :rtype: str
        """
        return self._template_source

    @template_source.setter
    def template_source(self, template_source):
        """Sets the template_source of this ListParameterTemplatesRequest.


        :param template_source: The template_source of this ListParameterTemplatesRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["System", "User"]  # noqa: E501
        if (self._configuration.client_side_validation and
                template_source not in allowed_values):
            raise ValueError(
                "Invalid value for `template_source` ({0}), must be one of {1}"  # noqa: E501
                .format(template_source, allowed_values)
            )

        self._template_source = template_source

    @property
    def template_type(self):
        """Gets the template_type of this ListParameterTemplatesRequest.  # noqa: E501


        :return: The template_type of this ListParameterTemplatesRequest.  # noqa: E501
        :rtype: str
        """
        return self._template_type

    @template_type.setter
    def template_type(self, template_type):
        """Sets the template_type of this ListParameterTemplatesRequest.


        :param template_type: The template_type of this ListParameterTemplatesRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["MySQL"]  # noqa: E501
        if (self._configuration.client_side_validation and
                template_type not in allowed_values):
            raise ValueError(
                "Invalid value for `template_type` ({0}), must be one of {1}"  # noqa: E501
                .format(template_type, allowed_values)
            )

        self._template_type = template_type

    @property
    def template_type_version(self):
        """Gets the template_type_version of this ListParameterTemplatesRequest.  # noqa: E501


        :return: The template_type_version of this ListParameterTemplatesRequest.  # noqa: E501
        :rtype: str
        """
        return self._template_type_version

    @template_type_version.setter
    def template_type_version(self, template_type_version):
        """Sets the template_type_version of this ListParameterTemplatesRequest.


        :param template_type_version: The template_type_version of this ListParameterTemplatesRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["MySQL_8_0", "MySQL_Community_5_7"]  # noqa: E501
        if (self._configuration.client_side_validation and
                template_type_version not in allowed_values):
            raise ValueError(
                "Invalid value for `template_type_version` ({0}), must be one of {1}"  # noqa: E501
                .format(template_type_version, allowed_values)
            )

        self._template_type_version = template_type_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ListParameterTemplatesRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListParameterTemplatesRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ListParameterTemplatesRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    vke

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ItemForListSupportedAddonsOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'categories': 'list[str]',
        'deploy_mode': 'str',
        'deploy_node_types': 'list[str]',
        'name': 'str',
        'necessary': 'str',
        'pod_network_modes': 'list[str]',
        'versions': 'list[VersionForListSupportedAddonsOutput]'
    }

    attribute_map = {
        'categories': 'Categories',
        'deploy_mode': 'DeployMode',
        'deploy_node_types': 'DeployNodeTypes',
        'name': 'Name',
        'necessary': 'Necessary',
        'pod_network_modes': 'PodNetworkModes',
        'versions': 'Versions'
    }

    def __init__(self, categories=None, deploy_mode=None, deploy_node_types=None, name=None, necessary=None, pod_network_modes=None, versions=None, _configuration=None):  # noqa: E501
        """ItemForListSupportedAddonsOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._categories = None
        self._deploy_mode = None
        self._deploy_node_types = None
        self._name = None
        self._necessary = None
        self._pod_network_modes = None
        self._versions = None
        self.discriminator = None

        if categories is not None:
            self.categories = categories
        if deploy_mode is not None:
            self.deploy_mode = deploy_mode
        if deploy_node_types is not None:
            self.deploy_node_types = deploy_node_types
        if name is not None:
            self.name = name
        if necessary is not None:
            self.necessary = necessary
        if pod_network_modes is not None:
            self.pod_network_modes = pod_network_modes
        if versions is not None:
            self.versions = versions

    @property
    def categories(self):
        """Gets the categories of this ItemForListSupportedAddonsOutput.  # noqa: E501


        :return: The categories of this ItemForListSupportedAddonsOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """Sets the categories of this ItemForListSupportedAddonsOutput.


        :param categories: The categories of this ItemForListSupportedAddonsOutput.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["Dns", "Gpu", "Image", "Monitor", "Network", "Scheduler", "Security", "Storage"]  # noqa: E501
        if (self._configuration.client_side_validation and
                not set(categories).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `categories` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(categories) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._categories = categories

    @property
    def deploy_mode(self):
        """Gets the deploy_mode of this ItemForListSupportedAddonsOutput.  # noqa: E501


        :return: The deploy_mode of this ItemForListSupportedAddonsOutput.  # noqa: E501
        :rtype: str
        """
        return self._deploy_mode

    @deploy_mode.setter
    def deploy_mode(self, deploy_mode):
        """Sets the deploy_mode of this ItemForListSupportedAddonsOutput.


        :param deploy_mode: The deploy_mode of this ItemForListSupportedAddonsOutput.  # noqa: E501
        :type: str
        """

        self._deploy_mode = deploy_mode

    @property
    def deploy_node_types(self):
        """Gets the deploy_node_types of this ItemForListSupportedAddonsOutput.  # noqa: E501


        :return: The deploy_node_types of this ItemForListSupportedAddonsOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._deploy_node_types

    @deploy_node_types.setter
    def deploy_node_types(self, deploy_node_types):
        """Sets the deploy_node_types of this ItemForListSupportedAddonsOutput.


        :param deploy_node_types: The deploy_node_types of this ItemForListSupportedAddonsOutput.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["EdgeNode", "Node", "VirtualNode"]  # noqa: E501
        if (self._configuration.client_side_validation and
                not set(deploy_node_types).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `deploy_node_types` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(deploy_node_types) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._deploy_node_types = deploy_node_types

    @property
    def name(self):
        """Gets the name of this ItemForListSupportedAddonsOutput.  # noqa: E501


        :return: The name of this ItemForListSupportedAddonsOutput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ItemForListSupportedAddonsOutput.


        :param name: The name of this ItemForListSupportedAddonsOutput.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def necessary(self):
        """Gets the necessary of this ItemForListSupportedAddonsOutput.  # noqa: E501


        :return: The necessary of this ItemForListSupportedAddonsOutput.  # noqa: E501
        :rtype: str
        """
        return self._necessary

    @necessary.setter
    def necessary(self, necessary):
        """Sets the necessary of this ItemForListSupportedAddonsOutput.


        :param necessary: The necessary of this ItemForListSupportedAddonsOutput.  # noqa: E501
        :type: str
        """

        self._necessary = necessary

    @property
    def pod_network_modes(self):
        """Gets the pod_network_modes of this ItemForListSupportedAddonsOutput.  # noqa: E501


        :return: The pod_network_modes of this ItemForListSupportedAddonsOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._pod_network_modes

    @pod_network_modes.setter
    def pod_network_modes(self, pod_network_modes):
        """Sets the pod_network_modes of this ItemForListSupportedAddonsOutput.


        :param pod_network_modes: The pod_network_modes of this ItemForListSupportedAddonsOutput.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["CalicoBgp", "CalicoVxlan", "Flannel", "VpcCniDedicated", "VpcCniShared"]  # noqa: E501
        if (self._configuration.client_side_validation and
                not set(pod_network_modes).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `pod_network_modes` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(pod_network_modes) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._pod_network_modes = pod_network_modes

    @property
    def versions(self):
        """Gets the versions of this ItemForListSupportedAddonsOutput.  # noqa: E501


        :return: The versions of this ItemForListSupportedAddonsOutput.  # noqa: E501
        :rtype: list[VersionForListSupportedAddonsOutput]
        """
        return self._versions

    @versions.setter
    def versions(self, versions):
        """Sets the versions of this ItemForListSupportedAddonsOutput.


        :param versions: The versions of this ItemForListSupportedAddonsOutput.  # noqa: E501
        :type: list[VersionForListSupportedAddonsOutput]
        """

        self._versions = versions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ItemForListSupportedAddonsOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemForListSupportedAddonsOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ItemForListSupportedAddonsOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    rds_mysql

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DescribeDBInstanceResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'basic_info': 'BasicInfoForDescribeDBInstanceOutput',
        'connection_info': 'ConnectionInfoForDescribeDBInstanceOutput',
        'data_sync_mode': 'str',
        'storage_type': 'str'
    }

    attribute_map = {
        'basic_info': 'BasicInfo',
        'connection_info': 'ConnectionInfo',
        'data_sync_mode': 'DataSyncMode',
        'storage_type': 'StorageType'
    }

    def __init__(self, basic_info=None, connection_info=None, data_sync_mode=None, storage_type=None, _configuration=None):  # noqa: E501
        """DescribeDBInstanceResponse - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._basic_info = None
        self._connection_info = None
        self._data_sync_mode = None
        self._storage_type = None
        self.discriminator = None

        if basic_info is not None:
            self.basic_info = basic_info
        if connection_info is not None:
            self.connection_info = connection_info
        if data_sync_mode is not None:
            self.data_sync_mode = data_sync_mode
        if storage_type is not None:
            self.storage_type = storage_type

    @property
    def basic_info(self):
        """Gets the basic_info of this DescribeDBInstanceResponse.  # noqa: E501


        :return: The basic_info of this DescribeDBInstanceResponse.  # noqa: E501
        :rtype: BasicInfoForDescribeDBInstanceOutput
        """
        return self._basic_info

    @basic_info.setter
    def basic_info(self, basic_info):
        """Sets the basic_info of this DescribeDBInstanceResponse.


        :param basic_info: The basic_info of this DescribeDBInstanceResponse.  # noqa: E501
        :type: BasicInfoForDescribeDBInstanceOutput
        """

        self._basic_info = basic_info

    @property
    def connection_info(self):
        """Gets the connection_info of this DescribeDBInstanceResponse.  # noqa: E501


        :return: The connection_info of this DescribeDBInstanceResponse.  # noqa: E501
        :rtype: ConnectionInfoForDescribeDBInstanceOutput
        """
        return self._connection_info

    @connection_info.setter
    def connection_info(self, connection_info):
        """Sets the connection_info of this DescribeDBInstanceResponse.


        :param connection_info: The connection_info of this DescribeDBInstanceResponse.  # noqa: E501
        :type: ConnectionInfoForDescribeDBInstanceOutput
        """

        self._connection_info = connection_info

    @property
    def data_sync_mode(self):
        """Gets the data_sync_mode of this DescribeDBInstanceResponse.  # noqa: E501


        :return: The data_sync_mode of this DescribeDBInstanceResponse.  # noqa: E501
        :rtype: str
        """
        return self._data_sync_mode

    @data_sync_mode.setter
    def data_sync_mode(self, data_sync_mode):
        """Sets the data_sync_mode of this DescribeDBInstanceResponse.


        :param data_sync_mode: The data_sync_mode of this DescribeDBInstanceResponse.  # noqa: E501
        :type: str
        """
        allowed_values = ["Async", "SemiSync", "Sync"]  # noqa: E501
        if (self._configuration.client_side_validation and
                data_sync_mode not in allowed_values):
            raise ValueError(
                "Invalid value for `data_sync_mode` ({0}), must be one of {1}"  # noqa: E501
                .format(data_sync_mode, allowed_values)
            )

        self._data_sync_mode = data_sync_mode

    @property
    def storage_type(self):
        """Gets the storage_type of this DescribeDBInstanceResponse.  # noqa: E501


        :return: The storage_type of this DescribeDBInstanceResponse.  # noqa: E501
        :rtype: str
        """
        return self._storage_type

    @storage_type.setter
    def storage_type(self, storage_type):
        """Sets the storage_type of this DescribeDBInstanceResponse.


        :param storage_type: The storage_type of this DescribeDBInstanceResponse.  # noqa: E501
        :type: str
        """
        allowed_values = ["CloudStorage", "ESSDPL1", "ESSDPL2", "LocalSSD"]  # noqa: E501
        if (self._configuration.client_side_validation and
                storage_type not in allowed_values):
            raise ValueError(
                "Invalid value for `storage_type` ({0}), must be one of {1}"  # noqa: E501
                .format(storage_type, allowed_values)
            )

        self._storage_type = storage_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DescribeDBInstanceResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DescribeDBInstanceResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DescribeDBInstanceResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    ecs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from volcenginesdkecs.models.account_for_describe_image_share_permission_output import AccountForDescribeImageSharePermissionOutput
from volcenginesdkecs.models.associate_instances_iam_role_request import AssociateInstancesIamRoleRequest
from volcenginesdkecs.models.associate_instances_iam_role_response import AssociateInstancesIamRoleResponse
from volcenginesdkecs.models.attach_key_pair_request import AttachKeyPairRequest
from volcenginesdkecs.models.attach_key_pair_response import AttachKeyPairResponse
from volcenginesdkecs.models.available_resource_for_describe_available_resource_output import AvailableResourceForDescribeAvailableResourceOutput
from volcenginesdkecs.models.available_zone_for_describe_available_resource_output import AvailableZoneForDescribeAvailableResourceOutput
from volcenginesdkecs.models.capacity_for_describe_deployment_sets_output import CapacityForDescribeDeploymentSetsOutput
from volcenginesdkecs.models.cpu_options_for_describe_instances_output import CpuOptionsForDescribeInstancesOutput
from volcenginesdkecs.models.create_deployment_set_request import CreateDeploymentSetRequest
from volcenginesdkecs.models.create_deployment_set_response import CreateDeploymentSetResponse
from volcenginesdkecs.models.create_image_request import CreateImageRequest
from volcenginesdkecs.models.create_image_response import CreateImageResponse
from volcenginesdkecs.models.create_key_pair_request import CreateKeyPairRequest
from volcenginesdkecs.models.create_key_pair_response import CreateKeyPairResponse
from volcenginesdkecs.models.create_tags_request import CreateTagsRequest
from volcenginesdkecs.models.create_tags_response import CreateTagsResponse
from volcenginesdkecs.models.delete_deployment_set_request import DeleteDeploymentSetRequest
from volcenginesdkecs.models.delete_deployment_set_response import DeleteDeploymentSetResponse
from volcenginesdkecs.models.delete_images_request import DeleteImagesRequest
from volcenginesdkecs.models.delete_images_response import DeleteImagesResponse
from volcenginesdkecs.models.delete_instance_request import DeleteInstanceRequest
from volcenginesdkecs.models.delete_instance_response import DeleteInstanceResponse
from volcenginesdkecs.models.delete_instances_request import DeleteInstancesRequest
from volcenginesdkecs.models.delete_instances_response import DeleteInstancesResponse
from volcenginesdkecs.models.delete_key_pairs_request import DeleteKeyPairsRequest
from volcenginesdkecs.models.delete_key_pairs_response import DeleteKeyPairsResponse
from volcenginesdkecs.models.delete_tags_request import DeleteTagsRequest
from volcenginesdkecs.models.delete_tags_response import DeleteTagsResponse
from volcenginesdkecs.models.deployment_set_for_describe_deployment_sets_output import DeploymentSetForDescribeDeploymentSetsOutput
from volcenginesdkecs.models.describe_available_resource_request import DescribeAvailableResourceRequest
from volcenginesdkecs.models.describe_available_resource_response import DescribeAvailableResourceResponse
from volcenginesdkecs.models.describe_deployment_set_supported_instance_type_family_request import DescribeDeploymentSetSupportedInstanceTypeFamilyRequest
from volcenginesdkecs.models.describe_deployment_set_supported_instance_type_family_response import DescribeDeploymentSetSupportedInstanceTypeFamilyResponse
from volcenginesdkecs.models.describe_deployment_sets_request import DescribeDeploymentSetsRequest
from volcenginesdkecs.models.describe_deployment_sets_response import DescribeDeploymentSetsResponse
from volcenginesdkecs.models.describe_image_share_permission_request import DescribeImageSharePermissionRequest
from volcenginesdkecs.models.describe_image_share_permission_response import DescribeImageSharePermissionResponse
from volcenginesdkecs.models.describe_images_request import DescribeImagesRequest
from volcenginesdkecs.models.describe_images_response import DescribeImagesResponse
from volcenginesdkecs.models.describe_instance_ecs_terminal_url_request import DescribeInstanceECSTerminalUrlRequest
from volcenginesdkecs.models.describe_instance_ecs_terminal_url_response import DescribeInstanceECSTerminalUrlResponse
from volcenginesdkecs.models.describe_instance_type_families_request import DescribeInstanceTypeFamiliesRequest
from volcenginesdkecs.models.describe_instance_type_families_response import DescribeInstanceTypeFamiliesResponse
from volcenginesdkecs.models.describe_instance_types_request import DescribeInstanceTypesRequest
from volcenginesdkecs.models.describe_instance_types_response import DescribeInstanceTypesResponse
from volcenginesdkecs.models.describe_instance_vnc_url_request import DescribeInstanceVncUrlRequest
from volcenginesdkecs.models.describe_instance_vnc_url_response import DescribeInstanceVncUrlResponse
from volcenginesdkecs.models.describe_instances_iam_roles_request import DescribeInstancesIamRolesRequest
from volcenginesdkecs.models.describe_instances_iam_roles_response import DescribeInstancesIamRolesResponse
from volcenginesdkecs.models.describe_instances_request import DescribeInstancesRequest
from volcenginesdkecs.models.describe_instances_response import DescribeInstancesResponse
from volcenginesdkecs.models.describe_key_pairs_request import DescribeKeyPairsRequest
from volcenginesdkecs.models.describe_key_pairs_response import DescribeKeyPairsResponse
from volcenginesdkecs.models.describe_system_events_request import DescribeSystemEventsRequest
from volcenginesdkecs.models.describe_system_events_response import DescribeSystemEventsResponse
from volcenginesdkecs.models.describe_tags_request import DescribeTagsRequest
from volcenginesdkecs.models.describe_tags_response import DescribeTagsResponse
from volcenginesdkecs.models.describe_tasks_request import DescribeTasksRequest
from volcenginesdkecs.models.describe_tasks_response import DescribeTasksResponse
from volcenginesdkecs.models.describe_user_data_request import DescribeUserDataRequest
from volcenginesdkecs.models.describe_user_data_response import DescribeUserDataResponse
from volcenginesdkecs.models.describe_zones_request import DescribeZonesRequest
from volcenginesdkecs.models.describe_zones_response import DescribeZonesResponse
from volcenginesdkecs.models.detach_key_pair_request import DetachKeyPairRequest
from volcenginesdkecs.models.detach_key_pair_response import DetachKeyPairResponse
from volcenginesdkecs.models.disassociate_instances_iam_role_request import DisassociateInstancesIamRoleRequest
from volcenginesdkecs.models.disassociate_instances_iam_role_response import DisassociateInstancesIamRoleResponse
from volcenginesdkecs.models.eip_address_for_describe_instances_output import EipAddressForDescribeInstancesOutput
from volcenginesdkecs.models.error_for_associate_instances_iam_role_output import ErrorForAssociateInstancesIamRoleOutput
from volcenginesdkecs.models.error_for_attach_key_pair_output import ErrorForAttachKeyPairOutput
from volcenginesdkecs.models.error_for_create_tags_output import ErrorForCreateTagsOutput
from volcenginesdkecs.models.error_for_delete_images_output import ErrorForDeleteImagesOutput
from volcenginesdkecs.models.error_for_delete_instances_output import ErrorForDeleteInstancesOutput
from volcenginesdkecs.models.error_for_delete_key_pairs_output import ErrorForDeleteKeyPairsOutput
from volcenginesdkecs.models.error_for_delete_tags_output import ErrorForDeleteTagsOutput
from volcenginesdkecs.models.error_for_detach_key_pair_output import ErrorForDetachKeyPairOutput
from volcenginesdkecs.models.error_for_disassociate_instances_iam_role_output import ErrorForDisassociateInstancesIamRoleOutput
from volcenginesdkecs.models.error_for_reboot_instances_output import ErrorForRebootInstancesOutput
from volcenginesdkecs.models.error_for_start_instances_output import ErrorForStartInstancesOutput
from volcenginesdkecs.models.error_for_stop_instances_output import ErrorForStopInstancesOutput
from volcenginesdkecs.models.error_for_update_system_events_output import ErrorForUpdateSystemEventsOutput
from volcenginesdkecs.models.export_image_request import ExportImageRequest
from volcenginesdkecs.models.export_image_response import ExportImageResponse
from volcenginesdkecs.models.gpu_device_for_describe_instance_types_output import GpuDeviceForDescribeInstanceTypesOutput
from volcenginesdkecs.models.gpu_for_describe_instance_types_output import GpuForDescribeInstanceTypesOutput
from volcenginesdkecs.models.image_for_describe_images_output import ImageForDescribeImagesOutput
from volcenginesdkecs.models.import_image_request import ImportImageRequest
from volcenginesdkecs.models.import_image_response import ImportImageResponse
from volcenginesdkecs.models.import_key_pair_request import ImportKeyPairRequest
from volcenginesdkecs.models.import_key_pair_response import ImportKeyPairResponse
from volcenginesdkecs.models.instance_for_describe_instances_output import InstanceForDescribeInstancesOutput
from volcenginesdkecs.models.instance_type_family_for_describe_instance_type_families_output import InstanceTypeFamilyForDescribeInstanceTypeFamiliesOutput
from volcenginesdkecs.models.instance_type_for_describe_instance_types_output import InstanceTypeForDescribeInstanceTypesOutput
from volcenginesdkecs.models.instances_iam_role_for_describe_instances_iam_roles_output import InstancesIamRoleForDescribeInstancesIamRolesOutput
from volcenginesdkecs.models.key_pair_for_describe_key_pairs_output import KeyPairForDescribeKeyPairsOutput
from volcenginesdkecs.models.local_volume_for_describe_instance_types_output import LocalVolumeForDescribeInstanceTypesOutput
from volcenginesdkecs.models.local_volume_for_describe_instances_output import LocalVolumeForDescribeInstancesOutput
from volcenginesdkecs.models.memory_for_describe_instance_types_output import MemoryForDescribeInstanceTypesOutput
from volcenginesdkecs.models.modify_deployment_set_attribute_request import ModifyDeploymentSetAttributeRequest
from volcenginesdkecs.models.modify_deployment_set_attribute_response import ModifyDeploymentSetAttributeResponse
from volcenginesdkecs.models.modify_image_attribute_request import ModifyImageAttributeRequest
from volcenginesdkecs.models.modify_image_attribute_response import ModifyImageAttributeResponse
from volcenginesdkecs.models.modify_image_share_permission_request import ModifyImageSharePermissionRequest
from volcenginesdkecs.models.modify_image_share_permission_response import ModifyImageSharePermissionResponse
from volcenginesdkecs.models.modify_instance_attribute_request import ModifyInstanceAttributeRequest
from volcenginesdkecs.models.modify_instance_attribute_response import ModifyInstanceAttributeResponse
from volcenginesdkecs.models.modify_instance_charge_type_request import ModifyInstanceChargeTypeRequest
from volcenginesdkecs.models.modify_instance_charge_type_response import ModifyInstanceChargeTypeResponse
from volcenginesdkecs.models.modify_instance_deployment_request import ModifyInstanceDeploymentRequest
from volcenginesdkecs.models.modify_instance_deployment_response import ModifyInstanceDeploymentResponse
from volcenginesdkecs.models.modify_instance_spec_request import ModifyInstanceSpecRequest
from volcenginesdkecs.models.modify_instance_spec_response import ModifyInstanceSpecResponse
from volcenginesdkecs.models.modify_key_pair_attribute_request import ModifyKeyPairAttributeRequest
from volcenginesdkecs.models.modify_key_pair_attribute_response import ModifyKeyPairAttributeResponse
from volcenginesdkecs.models.network_for_describe_instance_types_output import NetworkForDescribeInstanceTypesOutput
from volcenginesdkecs.models.network_interface_for_describe_instances_output import NetworkInterfaceForDescribeInstancesOutput
from volcenginesdkecs.models.network_interface_for_run_instances_input import NetworkInterfaceForRunInstancesInput
from volcenginesdkecs.models.operation_detail_for_associate_instances_iam_role_output import OperationDetailForAssociateInstancesIamRoleOutput
from volcenginesdkecs.models.operation_detail_for_attach_key_pair_output import OperationDetailForAttachKeyPairOutput
from volcenginesdkecs.models.operation_detail_for_create_tags_output import OperationDetailForCreateTagsOutput
from volcenginesdkecs.models.operation_detail_for_delete_images_output import OperationDetailForDeleteImagesOutput
from volcenginesdkecs.models.operation_detail_for_delete_instances_output import OperationDetailForDeleteInstancesOutput
from volcenginesdkecs.models.operation_detail_for_delete_key_pairs_output import OperationDetailForDeleteKeyPairsOutput
from volcenginesdkecs.models.operation_detail_for_delete_tags_output import OperationDetailForDeleteTagsOutput
from volcenginesdkecs.models.operation_detail_for_detach_key_pair_output import OperationDetailForDetachKeyPairOutput
from volcenginesdkecs.models.operation_detail_for_disassociate_instances_iam_role_output import OperationDetailForDisassociateInstancesIamRoleOutput
from volcenginesdkecs.models.operation_detail_for_reboot_instances_output import OperationDetailForRebootInstancesOutput
from volcenginesdkecs.models.operation_detail_for_start_instances_output import OperationDetailForStartInstancesOutput
from volcenginesdkecs.models.operation_detail_for_stop_instances_output import OperationDetailForStopInstancesOutput
from volcenginesdkecs.models.operation_detail_for_update_system_events_output import OperationDetailForUpdateSystemEventsOutput
from volcenginesdkecs.models.processor_for_describe_instance_types_output import ProcessorForDescribeInstanceTypesOutput
from volcenginesdkecs.models.rdma_for_describe_instance_types_output import RdmaForDescribeInstanceTypesOutput
from volcenginesdkecs.models.reboot_instance_request import RebootInstanceRequest
from volcenginesdkecs.models.reboot_instance_response import RebootInstanceResponse
from volcenginesdkecs.models.reboot_instances_request import RebootInstancesRequest
from volcenginesdkecs.models.reboot_instances_response import RebootInstancesResponse
from volcenginesdkecs.models.renew_instance_request import RenewInstanceRequest
from volcenginesdkecs.models.renew_instance_response import RenewInstanceResponse
from volcenginesdkecs.models.replace_system_volume_request import ReplaceSystemVolumeRequest
from volcenginesdkecs.models.replace_system_volume_response import ReplaceSystemVolumeResponse
from volcenginesdkecs.models.run_instances_request import RunInstancesRequest
from volcenginesdkecs.models.run_instances_response import RunInstancesResponse
from volcenginesdkecs.models.start_instance_request import StartInstanceRequest
from volcenginesdkecs.models.start_instance_response import StartInstanceResponse
from volcenginesdkecs.models.start_instances_request import StartInstancesRequest
from volcenginesdkecs.models.start_instances_response import StartInstancesResponse
from volcenginesdkecs.models.stop_instance_request import StopInstanceRequest
from volcenginesdkecs.models.stop_instance_response import StopInstanceResponse
from volcenginesdkecs.models.stop_instances_request import StopInstancesRequest
from volcenginesdkecs.models.stop_instances_response import StopInstancesResponse
from volcenginesdkecs.models.supported_resource_for_describe_available_resource_output import SupportedResourceForDescribeAvailableResourceOutput
from volcenginesdkecs.models.system_event_for_describe_system_events_output import SystemEventForDescribeSystemEventsOutput
from volcenginesdkecs.models.tag_filter_for_describe_instances_input import TagFilterForDescribeInstancesInput
from volcenginesdkecs.models.tag_filter_for_describe_tags_input import TagFilterForDescribeTagsInput
from volcenginesdkecs.models.tag_for_create_tags_input import TagForCreateTagsInput
from volcenginesdkecs.models.tag_for_describe_instances_output import TagForDescribeInstancesOutput
from volcenginesdkecs.models.tag_for_run_instances_input import TagForRunInstancesInput
from volcenginesdkecs.models.tag_resource_for_describe_tags_output import TagResourceForDescribeTagsOutput
from volcenginesdkecs.models.task_for_describe_tasks_output import TaskForDescribeTasksOutput
from volcenginesdkecs.models.update_system_events_request import UpdateSystemEventsRequest
from volcenginesdkecs.models.update_system_events_response import UpdateSystemEventsResponse
from volcenginesdkecs.models.volume_for_describe_instance_types_output import VolumeForDescribeInstanceTypesOutput
from volcenginesdkecs.models.volume_for_run_instances_input import VolumeForRunInstancesInput
from volcenginesdkecs.models.zone_for_describe_zones_output import ZoneForDescribeZonesOutput



# coding: utf-8

"""
    redis

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DescribeSlowLogsRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'context': 'str',
        'db_name': 'str',
        'instance_id': 'str',
        'node_ids': 'list[str]',
        'page_size': 'int',
        'query_end_time': 'str',
        'query_start_time': 'str'
    }

    attribute_map = {
        'context': 'Context',
        'db_name': 'DBName',
        'instance_id': 'InstanceId',
        'node_ids': 'NodeIds',
        'page_size': 'PageSize',
        'query_end_time': 'QueryEndTime',
        'query_start_time': 'QueryStartTime'
    }

    def __init__(self, context=None, db_name=None, instance_id=None, node_ids=None, page_size=None, query_end_time=None, query_start_time=None, _configuration=None):  # noqa: E501
        """DescribeSlowLogsRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._context = None
        self._db_name = None
        self._instance_id = None
        self._node_ids = None
        self._page_size = None
        self._query_end_time = None
        self._query_start_time = None
        self.discriminator = None

        if context is not None:
            self.context = context
        if db_name is not None:
            self.db_name = db_name
        self.instance_id = instance_id
        if node_ids is not None:
            self.node_ids = node_ids
        self.page_size = page_size
        if query_end_time is not None:
            self.query_end_time = query_end_time
        if query_start_time is not None:
            self.query_start_time = query_start_time

    @property
    def context(self):
        """Gets the context of this DescribeSlowLogsRequest.  # noqa: E501


        :return: The context of this DescribeSlowLogsRequest.  # noqa: E501
        :rtype: str
        """
        return self._context

    @context.setter
    def context(self, context):
        """Sets the context of this DescribeSlowLogsRequest.


        :param context: The context of this DescribeSlowLogsRequest.  # noqa: E501
        :type: str
        """

        self._context = context

    @property
    def db_name(self):
        """Gets the db_name of this DescribeSlowLogsRequest.  # noqa: E501


        :return: The db_name of this DescribeSlowLogsRequest.  # noqa: E501
        :rtype: str
        """
        return self._db_name

    @db_name.setter
    def db_name(self, db_name):
        """Sets the db_name of this DescribeSlowLogsRequest.


        :param db_name: The db_name of this DescribeSlowLogsRequest.  # noqa: E501
        :type: str
        """

        self._db_name = db_name

    @property
    def instance_id(self):
        """Gets the instance_id of this DescribeSlowLogsRequest.  # noqa: E501


        :return: The instance_id of this DescribeSlowLogsRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this DescribeSlowLogsRequest.


        :param instance_id: The instance_id of this DescribeSlowLogsRequest.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and instance_id is None:
            raise ValueError("Invalid value for `instance_id`, must not be `None`")  # noqa: E501

        self._instance_id = instance_id

    @property
    def node_ids(self):
        """Gets the node_ids of this DescribeSlowLogsRequest.  # noqa: E501


        :return: The node_ids of this DescribeSlowLogsRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._node_ids

    @node_ids.setter
    def node_ids(self, node_ids):
        """Sets the node_ids of this DescribeSlowLogsRequest.


        :param node_ids: The node_ids of this DescribeSlowLogsRequest.  # noqa: E501
        :type: list[str]
        """

        self._node_ids = node_ids

    @property
    def page_size(self):
        """Gets the page_size of this DescribeSlowLogsRequest.  # noqa: E501


        :return: The page_size of this DescribeSlowLogsRequest.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this DescribeSlowLogsRequest.


        :param page_size: The page_size of this DescribeSlowLogsRequest.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and page_size is None:
            raise ValueError("Invalid value for `page_size`, must not be `None`")  # noqa: E501

        self._page_size = page_size

    @property
    def query_end_time(self):
        """Gets the query_end_time of this DescribeSlowLogsRequest.  # noqa: E501


        :return: The query_end_time of this DescribeSlowLogsRequest.  # noqa: E501
        :rtype: str
        """
        return self._query_end_time

    @query_end_time.setter
    def query_end_time(self, query_end_time):
        """Sets the query_end_time of this DescribeSlowLogsRequest.


        :param query_end_time: The query_end_time of this DescribeSlowLogsRequest.  # noqa: E501
        :type: str
        """

        self._query_end_time = query_end_time

    @property
    def query_start_time(self):
        """Gets the query_start_time of this DescribeSlowLogsRequest.  # noqa: E501


        :return: The query_start_time of this DescribeSlowLogsRequest.  # noqa: E501
        :rtype: str
        """
        return self._query_start_time

    @query_start_time.setter
    def query_start_time(self, query_start_time):
        """Sets the query_start_time of this DescribeSlowLogsRequest.


        :param query_start_time: The query_start_time of this DescribeSlowLogsRequest.  # noqa: E501
        :type: str
        """

        self._query_start_time = query_start_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DescribeSlowLogsRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DescribeSlowLogsRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DescribeSlowLogsRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    vke

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ItemForListAddonsOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cluster_id': 'str',
        'cluster_type': 'str',
        'config': 'str',
        'create_client_token': 'str',
        'create_time': 'str',
        'deploy_mode': 'str',
        'deploy_node_type': 'str',
        'name': 'str',
        'status': 'StatusForListAddonsOutput',
        'update_client_token': 'str',
        'update_time': 'str',
        'version': 'str'
    }

    attribute_map = {
        'cluster_id': 'ClusterId',
        'cluster_type': 'ClusterType',
        'config': 'Config',
        'create_client_token': 'CreateClientToken',
        'create_time': 'CreateTime',
        'deploy_mode': 'DeployMode',
        'deploy_node_type': 'DeployNodeType',
        'name': 'Name',
        'status': 'Status',
        'update_client_token': 'UpdateClientToken',
        'update_time': 'UpdateTime',
        'version': 'Version'
    }

    def __init__(self, cluster_id=None, cluster_type=None, config=None, create_client_token=None, create_time=None, deploy_mode=None, deploy_node_type=None, name=None, status=None, update_client_token=None, update_time=None, version=None, _configuration=None):  # noqa: E501
        """ItemForListAddonsOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cluster_id = None
        self._cluster_type = None
        self._config = None
        self._create_client_token = None
        self._create_time = None
        self._deploy_mode = None
        self._deploy_node_type = None
        self._name = None
        self._status = None
        self._update_client_token = None
        self._update_time = None
        self._version = None
        self.discriminator = None

        if cluster_id is not None:
            self.cluster_id = cluster_id
        if cluster_type is not None:
            self.cluster_type = cluster_type
        if config is not None:
            self.config = config
        if create_client_token is not None:
            self.create_client_token = create_client_token
        if create_time is not None:
            self.create_time = create_time
        if deploy_mode is not None:
            self.deploy_mode = deploy_mode
        if deploy_node_type is not None:
            self.deploy_node_type = deploy_node_type
        if name is not None:
            self.name = name
        if status is not None:
            self.status = status
        if update_client_token is not None:
            self.update_client_token = update_client_token
        if update_time is not None:
            self.update_time = update_time
        if version is not None:
            self.version = version

    @property
    def cluster_id(self):
        """Gets the cluster_id of this ItemForListAddonsOutput.  # noqa: E501


        :return: The cluster_id of this ItemForListAddonsOutput.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """Sets the cluster_id of this ItemForListAddonsOutput.


        :param cluster_id: The cluster_id of this ItemForListAddonsOutput.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def cluster_type(self):
        """Gets the cluster_type of this ItemForListAddonsOutput.  # noqa: E501


        :return: The cluster_type of this ItemForListAddonsOutput.  # noqa: E501
        :rtype: str
        """
        return self._cluster_type

    @cluster_type.setter
    def cluster_type(self, cluster_type):
        """Sets the cluster_type of this ItemForListAddonsOutput.


        :param cluster_type: The cluster_type of this ItemForListAddonsOutput.  # noqa: E501
        :type: str
        """

        self._cluster_type = cluster_type

    @property
    def config(self):
        """Gets the config of this ItemForListAddonsOutput.  # noqa: E501


        :return: The config of this ItemForListAddonsOutput.  # noqa: E501
        :rtype: str
        """
        return self._config

    @config.setter
    def config(self, config):
        """Sets the config of this ItemForListAddonsOutput.


        :param config: The config of this ItemForListAddonsOutput.  # noqa: E501
        :type: str
        """

        self._config = config

    @property
    def create_client_token(self):
        """Gets the create_client_token of this ItemForListAddonsOutput.  # noqa: E501


        :return: The create_client_token of this ItemForListAddonsOutput.  # noqa: E501
        :rtype: str
        """
        return self._create_client_token

    @create_client_token.setter
    def create_client_token(self, create_client_token):
        """Sets the create_client_token of this ItemForListAddonsOutput.


        :param create_client_token: The create_client_token of this ItemForListAddonsOutput.  # noqa: E501
        :type: str
        """

        self._create_client_token = create_client_token

    @property
    def create_time(self):
        """Gets the create_time of this ItemForListAddonsOutput.  # noqa: E501


        :return: The create_time of this ItemForListAddonsOutput.  # noqa: E501
        :rtype: str
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this ItemForListAddonsOutput.


        :param create_time: The create_time of this ItemForListAddonsOutput.  # noqa: E501
        :type: str
        """

        self._create_time = create_time

    @property
    def deploy_mode(self):
        """Gets the deploy_mode of this ItemForListAddonsOutput.  # noqa: E501


        :return: The deploy_mode of this ItemForListAddonsOutput.  # noqa: E501
        :rtype: str
        """
        return self._deploy_mode

    @deploy_mode.setter
    def deploy_mode(self, deploy_mode):
        """Sets the deploy_mode of this ItemForListAddonsOutput.


        :param deploy_mode: The deploy_mode of this ItemForListAddonsOutput.  # noqa: E501
        :type: str
        """

        self._deploy_mode = deploy_mode

    @property
    def deploy_node_type(self):
        """Gets the deploy_node_type of this ItemForListAddonsOutput.  # noqa: E501


        :return: The deploy_node_type of this ItemForListAddonsOutput.  # noqa: E501
        :rtype: str
        """
        return self._deploy_node_type

    @deploy_node_type.setter
    def deploy_node_type(self, deploy_node_type):
        """Sets the deploy_node_type of this ItemForListAddonsOutput.


        :param deploy_node_type: The deploy_node_type of this ItemForListAddonsOutput.  # noqa: E501
        :type: str
        """

        self._deploy_node_type = deploy_node_type

    @property
    def name(self):
        """Gets the name of this ItemForListAddonsOutput.  # noqa: E501


        :return: The name of this ItemForListAddonsOutput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ItemForListAddonsOutput.


        :param name: The name of this ItemForListAddonsOutput.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def status(self):
        """Gets the status of this ItemForListAddonsOutput.  # noqa: E501


        :return: The status of this ItemForListAddonsOutput.  # noqa: E501
        :rtype: StatusForListAddonsOutput
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ItemForListAddonsOutput.


        :param status: The status of this ItemForListAddonsOutput.  # noqa: E501
        :type: StatusForListAddonsOutput
        """

        self._status = status

    @property
    def update_client_token(self):
        """Gets the update_client_token of this ItemForListAddonsOutput.  # noqa: E501


        :return: The update_client_token of this ItemForListAddonsOutput.  # noqa: E501
        :rtype: str
        """
        return self._update_client_token

    @update_client_token.setter
    def update_client_token(self, update_client_token):
        """Sets the update_client_token of this ItemForListAddonsOutput.


        :param update_client_token: The update_client_token of this ItemForListAddonsOutput.  # noqa: E501
        :type: str
        """

        self._update_client_token = update_client_token

    @property
    def update_time(self):
        """Gets the update_time of this ItemForListAddonsOutput.  # noqa: E501


        :return: The update_time of this ItemForListAddonsOutput.  # noqa: E501
        :rtype: str
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this ItemForListAddonsOutput.


        :param update_time: The update_time of this ItemForListAddonsOutput.  # noqa: E501
        :type: str
        """

        self._update_time = update_time

    @property
    def version(self):
        """Gets the version of this ItemForListAddonsOutput.  # noqa: E501


        :return: The version of this ItemForListAddonsOutput.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ItemForListAddonsOutput.


        :param version: The version of this ItemForListAddonsOutput.  # noqa: E501
        :type: str
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ItemForListAddonsOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemForListAddonsOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ItemForListAddonsOutput):
            return True

        return self.to_dict() != other.to_dict()
